#!/usr/bin/env python
import pygame
from pygame.locals import *
import sys

# bar.pyをインポート
import cursor, tools, player, enemy, bar

SCR_RECT = Rect(0, 0, 640, 480)

class Main():
    def __init__(self):
        pygame.init()
        pygame.display.set_caption("sample")
        screen = pygame.display.set_mode(SCR_RECT.size)

        self.all = pygame.sprite.RenderUpdates()
        self.enemies = pygame.sprite.Group()
        player.Player.containers = self.all
        enemy.Enemy.containers = self.all, self.enemies

        self.enemy_1 = enemy.Enemy((150, 80))
        self.enemy_2 = enemy.Enemy((330, 400))
        self.player = player.Player((288, 200))

        self.bg = tools.load_image("data", "bg.png")
        self.bgx = 0
        self.scroll_speed = 3

        # HPバーのインスタンス化
        self.hp = bar.HealthBar(32, 32, 100, 12) # maxの値はwidth-4を割り切れる数にする

        clock = pygame.time.Clock()
        while True:
            clock.tick(30)
            self.update()
            self.draw(screen)
            pygame.display.update()
            self.key_handler()

    def update(self):
        self.bgx = (self.bgx - self.scroll_speed) % SCR_RECT.width
        self.all.update()
        self.collision_detection()
        # HPバーの更新
        self.hp.update()

    def draw(self, screen):
        screen.blit(self.bg, (self.bgx, 0))
        screen.blit(self.bg, (self.bgx - SCR_RECT.width, 0))
        self.all.draw(screen)
        # HPバーの描画
        self.hp.draw(screen)

    def key_handler(self):
        for event in pygame.event.get():
            if event.type == QUIT:
                pygame.quit()
                sys.exit()

    def collision_detection(self):
        enemy_collided = pygame.sprite.spritecollide(self.player, self.enemies, False)
        if enemy_collided:
            # プレイヤーが無敵でないなら、HPを-1する
            if self.player.invincible == False:
                self.hp.hp -= 1
                self.player.invincible = True

if __name__ == "__main__":
    Main()
